==> cohesity_management_sdk-1.6.10.tar.gz: cohesity_management_sdk-1.6.10/cohesity_management_sdk/models/environment_last_protection_run_stats_by_env_enum.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Cohesity Inc.

class EnvironmentLastProtectionRunStatsByEnvEnum(object):

    """Implementation of the 'Environment_LastProtectionRunStatsByEnv' enum.

    Specifies the environment.

    Attributes:
        KSQL: TODO: type description here.
        KKVM: TODO: type description here.
        KGCPNATIVE: TODO: type description here.
        KHYPERFLEX: TODO: type description here.
        KACROPOLIS: TODO: type description here.
        KEXCHANGE: TODO: type description here.
        KORACLE: TODO: type description here.
        KHYPERV: TODO: type description here.
        KAWSNATIVE: TODO: type description here.
        KAD: TODO: type description here.
        KFLASHBLADE: TODO: type description here.
        KGPFS: TODO: type description here.
        KNETAPP: TODO: type description here.
        KAZURENATIVE: TODO: type description here.
        KISILON: TODO: type description here.
        KPHYSICALFILES: TODO: type description here.
        KAWSSNAPSHOTMANAGER: TODO: type description here.
        KO365: TODO: type description here.
        KPURE: TODO: type description here.
        KPUPPETEER: TODO: type description here.
        KNIMBLE: TODO: type description here.
        KGENERICNAS: TODO: type description here.
        KHYPERVVSS: TODO: type description here.
        KVCD: TODO: type description here.
        KVIEW: TODO: type description here.
        KGCP: TODO: type description here.
        KAWS: TODO: type description here.
        KPHYSICAL: TODO: type description here.
        KAZURE: TODO: type description here.
        KVMWARE: TODO: type description here.
        KAGENT: TODO: type description here.
        KO365OUTLOOK: TODO: type description here.

    """

    KSQL = 'kSQL'

    KKVM = 'kKVM'

    KGCPNATIVE = 'kGCPNative'

    KHYPERFLEX = 'kHyperFlex'

    KACROPOLIS = 'kAcropolis'

    KEXCHANGE = 'kExchange'

    KORACLE = 'kOracle'

    K_HYPERV = 'kHyperV'

    KAWSNATIVE = 'kAWSNative'

    KAD = 'kAD'

    KFLASHBLADE = 'kFlashBlade'

    KGPFS = 'kGPFS'

    KNETAPP = 'kNetapp'

    KAZURENATIVE = 'kAzureNative'

    KISILON = 'kIsilon'

    KPHYSICALFILES = 'kPhysicalFiles'

    KAWSSNAPSHOTMANAGER = 'kAWSSnapshotManager'

    KO365 = 'kO365'

    KPURE = 'kPure'

    KPUPPETEER = 'kPuppeteer'

    KNIMBLE = 'kNimble'

    KGENERICNAS = 'kGenericNas'

    K_HYPERV_VSS = 'kHyperVVSS'

    KVCD = 'kVCD'

    KVIEW = 'kView'

    KGCP = 'kGCP'

    KAWS = 'kAWS'

    KPHYSICAL = 'kPhysical'

    KAZURE = 'kAzure'

    K_VMWARE = 'kVMware'

    KAGENT = 'kAgent'

    KO365OUTLOOK = 'kO365Outlook'

==> cohesity_management_sdk-1.9.1.tar.gz: cohesity_management_sdk-1.9.1/cohesity_management_sdk/models/environment_last_protection_run_stats_by_env_enum.py <==
# -*- coding: utf-8 -*-
# Copyright 2023 Cohesity Inc.

class EnvironmentLastProtectionRunStatsByEnvEnum(object):

    """Implementation of the 'EnvironmentLastProtectionRunStatsByEnv' enum.
    Specifies the environment.


    Attributes:
        KVMWARE: TODO: type description here.
        KHYPERV: TODO: type description here.
        KSQL: TODO: type description here.
        KVIEW: TODO: type description here.
        KPUPPETEER: TODO: type description here.
        KPHYSICAL: TODO: type description here.
        KPURE: TODO: type description here.
        KNIMBLE: TODO: type description here.
        KAZURE: TODO: type description here.
        KNETAPP: TODO: type description here.
        KAGENT: TODO: type description here.
        KGENERICNAS: TODO: type description here.
        KACROPOLIS: TODO: type description here.
        KPHYSICALFILES: TODO: type description here.
        KISILON: TODO: type description here.
        KGPFS: TODO: type description here.
        KKVM: TODO: type description here.
        KAWS: TODO: type description here.
        KEXCHANGE: TODO: type description here.
        KHYPERVVSS: TODO: type description here.
        KORACLE: TODO: type description here.
        KGCP: TODO: type description here.
        KFLASHBLADE: TODO: type description here.
        KAWSNATIVE: TODO: type description here.
        KVCD: TODO: type description here.
        KO365: TODO: type description here.
        KO365OUTLOOK: TODO: type description here.
        KHYPERFLEX: TODO: type description here.
        KGCPNATIVE: TODO: type description here.
        KAZURENATIVE: TODO: type description here.
        KAD: TODO: type description here.
        KAWSSNAPSHOTMANAGER: TODO: type description here.

    """

    K_VMWARE = 'kVMware'

    K_HYPERV = 'kHyperV'

    KSQL = 'kSQL'

    KVIEW = 'kView'

    KPUPPETEER = 'kPuppeteer'

    KPHYSICAL = 'kPhysical'

    KPURE = 'kPure'

    KNIMBLE = 'kNimble'

    KAZURE = 'kAzure'

    KNETAPP = 'kNetapp'

    KAGENT = 'kAgent'

    KGENERICNAS = 'kGenericNas'

    KACROPOLIS = 'kAcropolis'

    KPHYSICALFILES = 'kPhysicalFiles'

    KISILON = 'kIsilon'

    KGPFS = 'kGPFS'

    KKVM = 'kKVM'

    KAWS = 'kAWS'

    KEXCHANGE = 'kExchange'

    K_HYPERV_VSS = 'kHyperVVSS'

    KORACLE = 'kOracle'

    KGCP = 'kGCP'

    KFLASHBLADE = 'kFlashBlade'

    KAWSNATIVE = 'kAWSNative'

    KVCD = 'kVCD'

    KO365 = 'kO365'

    KO365OUTLOOK = 'kO365Outlook'

    KHYPERFLEX = 'kHyperFlex'

    KGCPNATIVE = 'kGCPNative'

    KAZURENATIVE = 'kAzureNative'

    KAD = 'kAD'

    KAWSSNAPSHOTMANAGER = 'kAWSSnapshotManager'
